@@ -36,7 +36,7 @@ class Test_MultiScreenWorker : public ::testing::Test
 TEST_F(Test_MultiScreenWorker, coverage_test)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     qDebug() << worker->dockRect("test screen");
 
@@ -47,7 +47,7 @@ TEST_F(Test_MultiScreenWorker, coverage_test)
     worker->updateDaemonDockSize(20);
 
     QDBusMessage msg;
-    worker->handleDbusSignal(msg);
+    worker->handleDBusSignal(msg);
 
     worker->onRegionMonitorChanged(0, 0, worker->m_registerKey);
 
@@ -59,7 +59,6 @@ TEST_F(Test_MultiScreenWorker, coverage_test)
     worker->checkXEventMonitorService();
     worker->showAniFinished();
     worker->hideAniFinished();
-    worker->primaryScreenChanged();
     worker->onRequestUpdateFrontendGeometry();
     worker->isCopyMode();
     worker->onRequestUpdatePosition(Dock::Position::Top, Dock::Position::Bottom);
@@ -74,7 +73,7 @@ TEST_F(Test_MultiScreenWorker, coverage_test)
 TEST_F(Test_MultiScreenWorker, onDisplayModeChanged)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->onDisplayModeChanged(static_cast<DisplayMode>(0));
     worker->m_hideMode = HideMode::KeepShowing;
@@ -99,7 +98,7 @@ TEST_F(Test_MultiScreenWorker, onDisplayModeChanged)
 TEST_F(Test_MultiScreenWorker, displayAnimation_onRequestUpdateRegionMonitor)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->m_position = Dock::Position::Left;
     worker->displayAnimation("primary", MultiScreenWorker::AniAction::Show);
@@ -138,7 +137,7 @@ TEST_F(Test_MultiScreenWorker, displayAnimation_onRequestUpdateRegionMonitor)
 TEST_F(Test_MultiScreenWorker, onTouchPress_onTouchRelease)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     QPoint p(0, 0);
     worker->rawXPosition(p);
@@ -174,7 +173,7 @@ TEST_F(Test_MultiScreenWorker, onTouchPress_onTouchRelease)
 TEST_F(Test_MultiScreenWorker, onDelayAutoHideChanged)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->m_hideMode = HideMode::SmartHide;
     worker->m_hideState = HideState::Show;
@@ -195,7 +194,7 @@ TEST_F(Test_MultiScreenWorker, onDelayAutoHideChanged)
 TEST_F(Test_MultiScreenWorker, onPositionChanged)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->m_hideMode = HideMode::KeepHidden;
     worker->onPositionChanged(static_cast<Position>(0));
@@ -220,7 +219,7 @@ TEST_F(Test_MultiScreenWorker, onPositionChanged)
 TEST_F(Test_MultiScreenWorker, reInitDisplayData)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->reInitDisplayData();
 
@@ -231,7 +230,7 @@ TEST_F(Test_MultiScreenWorker, reInitDisplayData)
 TEST_F(Test_MultiScreenWorker, onRequestUpdateMonitorInfo)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->onRequestUpdateMonitorInfo();
 
@@ -242,7 +241,7 @@ TEST_F(Test_MultiScreenWorker, onRequestUpdateMonitorInfo)
 TEST_F(Test_MultiScreenWorker, updateParentGeometry)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->updateParentGeometry(QRect(0, 0, 10, 10), Position::Top);
     worker->updateParentGeometry(QRect(0, 0, 10, 10), Position::Bottom);
@@ -256,7 +255,7 @@ TEST_F(Test_MultiScreenWorker, updateParentGeometry)
 TEST_F(Test_MultiScreenWorker, onWindowSizeChanged)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->onWindowSizeChanged(-1);
 
@@ -267,7 +266,7 @@ TEST_F(Test_MultiScreenWorker, onWindowSizeChanged)
 TEST_F(Test_MultiScreenWorker, updateDisplay)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->updateDisplay();
 
@@ -278,7 +277,7 @@ TEST_F(Test_MultiScreenWorker, updateDisplay)
 TEST_F(Test_MultiScreenWorker, onExtralRegionMonitorChanged)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->onExtralRegionMonitorChanged(0, 0, "test");
 
@@ -300,7 +299,7 @@ TEST_F(Test_MultiScreenWorker, onExtralRegionMonitorChanged)
 TEST_F(Test_MultiScreenWorker, onRegionMonitorChanged)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->onRegionMonitorChanged(0, 0, "test");
 
@@ -325,7 +324,7 @@ TEST_F(Test_MultiScreenWorker, dockScreen)
 TEST_F(Test_MultiScreenWorker, screenworker_test3)
 {
     MainWindow window;
-    MultiScreenWorker *worker = new MultiScreenWorker(&window, DWindowManagerHelper::instance());
+    MultiScreenWorker *worker = new MultiScreenWorker(&window);
 
     worker->resetDockScreen();
 
