@@ -121,6 +121,69 @@
         <translation>Vaxt ayarları</translation>
     </message>
 </context>
+<context>
+    <name>DatetimeWidget</name>
+    <message>
+        <source>Monday</source>
+        <translation>Bazar ertəsi</translation>
+    </message>
+    <message>
+        <source>Tuesday</source>
+        <translation>Çərşənbə axşamı</translation>
+    </message>
+    <message>
+        <source>Wednesday</source>
+        <translation>Çərşənbə</translation>
+    </message>
+    <message>
+        <source>Thursday</source>
+        <translation>Cümə axşamı</translation>
+    </message>
+    <message>
+        <source>Friday</source>
+        <translation>Cümə</translation>
+    </message>
+    <message>
+        <source>Saturday</source>
+        <translation>Şənbə</translation>
+    </message>
+    <message>
+        <source>Sunday</source>
+        <translation>Bazar</translation>
+    </message>
+    <message>
+        <source>monday</source>
+        <translation>bazar ertəsi</translation>
+    </message>
+    <message>
+        <source>tuesday</source>
+        <translation>çərşənbə axşamı</translation>
+    </message>
+    <message>
+        <source>wednesday</source>
+        <translation>çərşənbə</translation>
+    </message>
+    <message>
+        <source>thursday</source>
+        <translation>cümə axşamı</translation>
+    </message>
+    <message>
+        <source>friday</source>
+        <translation>cümə</translation>
+    </message>
+    <message>
+        <source>saturday</source>
+        <translation>şənbə</translation>
+    </message>
+    <message>
+        <source>sunday</source>
+        <translation>bazar</translation>
+    </message>
+    <message>
+        <source>%1year%2month%3day</source>
+        <translation>%1il%2ay%3gün</translation>
+    </message>
+</context>
 <context>
     <name>DialogManager</name>
     <message>
@@ -248,14 +311,20 @@
     <message>
         <source>Size</source>
         <translation>Ölçü</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Multiple Displays</source>
         <translation>Çoxsaylı ekran</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Plugin Area</source>
         <translation>Plaqin sahəsi</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Select which icons appear in the Dock</source>
@@ -272,6 +341,8 @@
     <message>
         <source>Mode</source>
         <translation>Rejim</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Top</source>
@@ -292,6 +363,8 @@
     <message>
         <source>Location</source>
         <translation>Yerləşmə</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Keep shown</source>
@@ -308,6 +381,8 @@
     <message>
         <source>Status</source>
         <translation>Vəziyyəti</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Small</source>
@@ -400,7 +475,30 @@
     <message>
         <source>Dock</source>
         <translation>Dok panel</translation>
-        <extra-contents_path>/personalization/Dock</extra-contents_path>
+    </message>
+    <message>
+        <source>Mode</source>
+        <translation>Rejim</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>Yerləşmə</translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation>Vəziyyəti</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Ölçü</translation>
+    </message>
+    <message>
+        <source>Show Dock</source>
+        <translation>Dok paneli göstərmək</translation>
+    </message>
+    <message>
+        <source>Plugin Area</source>
+        <translation>Plaqin sahəsi</translation>
     </message>
 </context>
 <context>
@@ -456,8 +554,8 @@
 <context>
     <name>SoundApplet</name>
     <message>
-        <source>Device</source>
-        <translation>Avadanlıq</translation>
+        <source>Volume</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -478,6 +576,10 @@
         <source>Volume %1</source>
         <translation>Səs %1</translation>
     </message>
+    <message>
+        <source>No output devices</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SoundPlugin</name>
